@@ -34,6 +34,11 @@ import org.slf4j.LoggerFactory;
  */
 public class CatEngineStandard implements CatEngine {
 
+    /**
+     * The CAT engine singleton.
+     */
+    public static final CatEngine INSTANCE = new CatEngineStandard();
+
     /**
      * A Logger instance for the CAT engine.
      */
@@ -177,6 +182,12 @@ public class CatEngineStandard implements CatEngine {
      */
     private ExposureControlType exposureControlType;
 
+    /**
+     * Constructs a new {@link CatEngineStandard}.
+     */
+    private CatEngineStandard() {
+    }
+
     /**
      * {@inheritDoc}
      *
@@ -185,8 +196,8 @@ public class CatEngineStandard implements CatEngine {
     @Override
     public CatOutput runsCatCycle(CatInput catInput) throws IOException, InfeasibleTestConfigException {
         completedCount = catInput.getCompletedCount();
-        LOGGER.debug("runsCatCycle starts for stage " + completedCount);
-        final long startTime = System.currentTimeMillis();
+        LOGGER.debug("runsCatCycle starts for stage {}", completedCount);
+        long startTime = System.currentTimeMillis();
         initialize(catInput);
         if (completedCount > testLength) {
             throw new IllegalArgumentException("Number of items completed cannot exceed total items");
@@ -204,6 +215,7 @@ public class CatEngineStandard implements CatEngine {
             if (completedCount == 0) {
                 initializeShadowTestRun(catInput);
             }
+            startTime = System.currentTimeMillis();
             setupShadowTestRun(catInput);
             refreshShadowTest(catInput);
         }
@@ -216,8 +228,7 @@ public class CatEngineStandard implements CatEngine {
         CatOutput catOutput = new CatOutputStandard(itemsToAdminister, thetaEst, testComplete,
                 passageOrItemEligibilityAtThetaRange, shadowTest, catEngineTime, Precision.round(solverTimeSecs, 3));
 
-        LOGGER.debug(
-                "runsCatCycle ends for stage " + completedCount + " with CAT engine time " + catEngineTime + " second");
+        LOGGER.debug("runsCatCycle ends for stage {} with CAT engine time {}second", completedCount, catEngineTime);
         return catOutput;
     }
 
@@ -234,7 +245,8 @@ public class CatEngineStandard implements CatEngine {
         // Calculate information values for all items
         double[] fisherInformation = null;
         if (catInput.getCatConfig().scoringMethodConfig().scoringMethod().equals(ScoringMethod.SUPPORTED_METHODS.EAP)) {
-            fisherInformation = CatFunctions.calcInfo(itemPar, thetaEst.getTheta());
+            fisherInformation = ItemSelectionMethodFactory.getInstance(catInput.getCatConfig().itemSelectionMethod(),
+                    itemPar, thetaEst.getTheta(), thetaEst.getSe()).getSelectionCriteria();
         } else {
             throw new IllegalArgumentException("The scoring method specified is not supported!");
         }
@@ -315,9 +327,9 @@ public class CatEngineStandard implements CatEngine {
         // CBC solver doesn't return correct infeasible status. Need additional checking
         // on solutions
         if (outputData.getSolverStatus().equals(SolverOutput.SOLVER_STATS.INFEASIBLE) ||
-                outputData.getSelectedItemIdentifiers().size() == 0) {
+                outputData.getSelectedItemIdentifiers().isEmpty()) {
             throw new InfeasibleTestConfigException("Test configuration is not feasible." +
-                    " Please check the configuration parameters and/or constraitns");
+                    "Please check the configuration parameters and/or constraitns");
         }
 
         solverTimeSecs = shadowTestRun.getTestAssembly().getTotalSolverTime();
@@ -326,9 +338,6 @@ public class CatEngineStandard implements CatEngine {
         itemsToAdminister = prepShadowTest(itemsAdministeredString, outputData.getSelectedItemRowIndicesArray(),
                 mapIndices, catInput.getTestConfig().getItemPoolTable(), passagePoolTable,
                 outputData.getPassageRowIndexSequence());
-
-        // save shadow test and relaxed item or passage identifiers for audit
-        // shadowTest = itemsToAdminister.getAllItems();
         shadowTest = outputData.getSelectedItemIdentifiers();
     }
 
@@ -414,14 +423,14 @@ public class CatEngineStandard implements CatEngine {
      * @param catInput the {@link CatInput} data
      * @throws IOException if there is an IO error
      */
-    private void setupShadowTestRun(CatInput catInput) throws IOException {
+    private void setupShadowTestRun(CatInput catInput) {
         if (catInput.getAdaptiveStage() == 0) {
 
             // if this is the first stage of the test, use initial theta value
             double initTheta = catInput.getCatConfig().initTheta();
             if (catInput.getCatConfig().scoringMethodConfig().scoringMethod()
                     .equals(ScoringMethod.SUPPORTED_METHODS.EAP)) {
-                thetaEst = new ThetaEst(initTheta, 0.0d);
+                thetaEst = new ThetaEst(initTheta, 1.0d);
             } else {
                 throw new IllegalArgumentException("The scoring method is not supported!");
             }
@@ -513,7 +522,7 @@ public class CatEngineStandard implements CatEngine {
         }
 
         // initialize returned values
-        shadowTest = new ArrayList<String>(testLength);
+        shadowTest = new ArrayList<>(testLength);
 
         // set initial exposure control values
         // exposureType indicates whether exposure control is at the passage or
